@@ -43,7 +43,7 @@ import sys
 import uuid
 import zipfile
 
-__version__ = "0.3.58"
+__version__ = "0.3.60"
 
 __EXITOKAY__ = 0
 FILE_DIR = ".pyppyn"
@@ -195,9 +195,8 @@ class ConfigRep:
 
         if wheel_file is not None:
             logger.info("Unzipping: %s", wheel_file)
-            zip_ref = zipfile.ZipFile(wheel_file, "r")
-            zip_ref.extractall(ConfigRep.WHEEL_TEMP_DIR)
-            zip_ref.close()
+            with zipfile.ZipFile(wheel_file, "r") as zip_ref:
+                zip_ref.extractall(ConfigRep.WHEEL_TEMP_DIR)
 
     def _wheel_directories(self):
         # look at directories wheel created
@@ -220,21 +219,24 @@ class ConfigRep:
     def _wheel_console_scripts(self):
         # console scripts
         logger.info("Reading names of console scripts")
-        ep_file = open("entry_points.txt", "r")
         self.config["console_scripts"] = []
         console_scripts = False
-        for line in ep_file:
-            if line.startswith("[console_scripts]"):
-                console_scripts = True
-            elif console_scripts:
-                parts = line.split(" = ")
-                if len(parts) > 1:
-                    self.config["console_scripts"].append(parts[0].strip())
+        with open("entry_points.txt", "r") as ep_file:
+            for line in ep_file:
+                if line.startswith("[console_scripts]"):
+                    console_scripts = True
+                elif console_scripts:
+                    parts = line.split(" = ")
+                    if len(parts) > 1:
+                        self.config["console_scripts"].append(parts[0].strip())
 
     def _wheel_metadata(self):
         # metadata
         logger.info("Reading wheel metadata")
-        bulk = open("METADATA", "r").read()
+        bulk = ""
+        with open("METADATA", "r") as metadata_fh:
+            bulk = metadata_fh.read()
+
         parts = bulk.split("\n\n")
         if len(parts) > 1:
             metadata = parts[0].strip()
